;OShell-82 version 2.5
;Assembly include file for TI-82 object assembling

#DEFINE ROM_CALL(INDEX) CALL $8D28 \ .DB INDEX  ; Access to ROM routines
#DEFINE CALL_Z(ADDR)    CALL $8D2B \ .DW ADDR   ; ALL programs USE THESE
#DEFINE CALL_(ADDR)     CALL $8D2E \ .DW ADDR   ;       instead of a normal
#DEFINE CALL_NZ(ADDR)   CALL $8D31 \ .DW ADDR   ;       CALL instruction
#DEFINE CALL_C(ADDR)    CALL $8D37 \ .DW ADDR   ;  "    "
#DEFINE CALL_NC(ADDR)   CALL $8D3D \ .DW ADDR   ;  "    "
#DEFINE JUMP_Z(ADDR)    CALL $8D43 \ .DW ADDR   ; Use these if the normal
#DEFINE JUMP_(ADDR)     CALL $8D46 \ .DW ADDR   ;       relative jump has too
#DEFINE JUMP_NZ(ADDR)   CALL $8D49 \ .DW ADDR   ;       far to go
#DEFINE JUMP_C(ADDR)    CALL $8D4F \ .DW ADDR   ;  "    "
#DEFINE JUMP_NC(ADDR)   CALL $8D55 \ .DW ADDR   ;  "    "

;TI-82 universal ROM routine addresses - same in all versions, use CALL
LD_HL_MHL       =$0033  ; HL=(HL), A=L
CP_HL_DE        =$0095  ; CP HL,DE (modifies flags only)
UNPACK_HL       =$00A1  ; Unpack one digit of HL into A (used in D_HL_DECI)
STORE_KEY       =$01C7  ; Store immediate keystroke from A
;NOTE:  I haven't yet been able to get any output from GET_KEY although the
;       immediate code at $01D4 is the same as the TI-85's GET_KEY routine...
;       Therefore, I suggest you use ROM_CALL(_getkey) which is the same as
;       the TI-83's _getkey routine...
GET_KEY         =$01D4  ; Get immediate keystroke into A
FIND_PIXEL      =$4116  ; Be sure to set ROM page to 4 first!

;OShell-82 2.5 Public data areas/variables
PROGRAM_ADDR    =$8D5B  ; RAM location of currently executing program
OS_VER          =$8D5D  ; OShell version number (top 4 bits = major version)
OS_BITS         =$8D5E  ; OShell status byte (currently only used internally)

;These names are reserved for the ROM_CALL() macro
TX_CHARPUT      =$00    ; Normal text display translated CHAR of A
D_LT_STR        =$01    ; Normal text display length-indexed string at HL
M_CHARPUT       =$02    ; Small text display CHAR of A
D_ZM_STR        =$03    ; Small text display ASCIIZ string at HL
SCROLL_UP       =$06    ; Scroll the screen up one line
TR_CHARPUT      =$07    ; Normal text display untranslated CHAR of A
CLEARLCD        =$08    ; Clear the LCD hardware only
D_HL_DECI       =$09    ; Normal text display right justified VALUE of HL
CLEARTEXT       =$0A    ; Set all the text memory to 00
D_ZT_STR        =$0B    ; Normal text display ASCIIZ string at HL
BUSY_OFF        =$0C    ; Turn off "busy" indicator
BUSY_ON         =$0D    ; Turn on "busy" indicator
_GETKEY         =$0E    ; Wait for and return getkey code (See KEYCODES.INC)
_GRBUFCPY_V     =$0F    ; Copies graph screen to LCD

;TI-82 RAM data areas/variables - I will expand on this later
KEY_0           =$8000  ; Translated scancode of last key, but 0 if gotten
LAST_KEY        =$8006  ; Last key pressed
CURSOR_ROW      =$800C  ; Normal text cursor row
CURSOR_COL      =$800D  ; Normal text cursor column
TEXT_MEM        =$808F  ; Text memory, 128 bytes
CURSOR_X        =$8215  ; Small text cursor column
CURSOR_Y        =$8216  ; Small text cursor row
_IY_TABLE       =$8528  ; This is the default value of IY in the ROM
GRAPH_MEM       =$88B8  ; Graph memory buffer - used in ROM_CALL(_grbufcpy_v)
TEXT_MEM2       =$8BDF  ; Secondary text memory, 128 bytes
VAT_START       =$FE6F  ; Beginning of VAT (works backwards)
STACK           =$FFFF  ; Beginning of STACK (also works backwards)

;TI-82 Hardware I/O Ports - USE AT YOUR OWN RISK
LINKPORT        =$00    ; Same functionality as the TI-85 port
KEYPAD          =$01    ; Same as TI-85
MISCPORT        =$02    ; ROM page switching, other functions...
LCDPOWER        =$03    ; Same as TI-85
MISCPORT2       =$04    ; Apparently same as TI-85 port
LCDINSTPORT     =$10    ; Apparently same as TI-83 port
LCDDATAPORT     =$11    ; Not much info on this one (TI-83?)

; Keys (added by Retupmoc 7)

K_NOKEY         =$00
K_DOWN          =$01
K_LEFT          =$02
K_RIGHT         =$03
K_UP            =$04
K_ENTER         =$09
K_PLUS          =$0A
K_MINUS         =$0B
K_STAR          =$0C
K_SLASH         =$0D
K_RAISE         =$0E
K_CLEAR         =$0F
K_SIGN          =$11
K_3             =$12
K_6             =$13
K_9             =$14
K_RIGHTPAR      =$15
K_TAN           =$16
K_CUSTOM        =$17
K_DOT           =$19
K_2             =$1A
K_5             =$1B
K_8             =$1C
K_LEFTPAR      =$1D
K_COS           =$1E
K_PRGM          =$1F
K_DEL           =$20
K_0             =$21
K_1             =$22
K_4             =$23
K_7             =$24
K_EE            =$25
K_SIN           =$26
K_STAT          =$27
K_XVAR          =$28
K_ON            =$29
K_STO           =$2A
K_COMMA         =$2B
K_SQUARE        =$2C
K_LN            =$2D
K_LOG           =$2E
K_GRAPH         =$2F
K_ALPHA         =$30
K_F5            =$31
K_F4            =$32
K_F3            =$33
K_F2            =$34
K_F1            =$35
K_SECOND        =$36
K_EXIT          =$37
K_MORE          =$38

